# Project Scope

Based on our conversations and the details you've provided, we've put together the below outline of your new design.

All new designs are built on our eCommerce framework, which comes with standard eCommerce features out of the box including shopping cart functionality, secure checkout, product search & filter functionality, customer account pages, and shipping cost calculators. This allows us to focus on creating a design that has a return on investment for your business.

## Aesthetic

- A fully responsive website that looks great on mobiles, tablets and desktop computers.
- A clean, modern design using the branding colours from your company logo.

---

## General (45m)

- *Please Note: The 'Product Compare/Comparison List' feature from your current site will not be included as it is not supported within Neto.*
- Create a new category page 'On Sale', which contains all your products currently on sale.<!-- 45m -->

---

## Header (19hr 30m)

### Desktop View

<!-- 
Coding 4hr
Mockup 1hr 30m (megamenu)
-->

![Desktop Header](https://store.neto.com.au/assets/scopes/WHH/header-desktop.png)

We'll create a design of the desktop header & menu for you to approve before implementing the final design. This will include:

- A 'Login/Register' link, once logged in change to 'My Account'.
- A 'My Wishlist' link, which when logged in takes a user to the wishlist section within the account page.<!-- 15m -->
- A 'Register For Wholesale Account' button, so that wholesale customers can register accounts.<!-- 15m -->
- *Please Note: The 'Product Compare/Comparison List' feature from your current site will not be included as it is not supported within Neto.*
- A clear search field.
- Details of current cart contents, including a dropdown that allows you to see further info, remove items, go to the cart page or checkout.
- Your company logo.
- A category mega menu which shows your top-level categories listed in a horizontal navbar, and sub-categories in a large menu when hovering over each of them. <!-- 2hr 30m -->
  - This menu has been quoted based on your current category tree, adding a large number of additional categories may break the layout.

![Megamenu](https://store.neto.com.au/assets/scopes/WHH/mega-menu.png)

### Mobile View

<!--
Wireframe 2hr
Mockup 3hr 
Coding 5hr
-->

![Mobile Header](https://store.neto.com.au/assets/scopes/WHH/header-mobile.png)

We'll create a design of the mobile header & menu for you to approve before implementing the final design. This will include:

- A clean header with your business logo, menu and cart button.
  - When the menu button is clicked/tapped display the menu in an accordion-style collapsible layout. <!-- 1hr -->
- A prominent full-width search field.

---

## Home Page (16hr)

<!--
Wireframe 3hr
Mockup 5hr 
Coding 5hr
-->

We'll create a design of the home page for you to approve before implementing the final design. This page will include:

- A large full-width carousel, with mobile responsive swipe gestures, slide indicator dots, and arrows. <!-- 45m -->
- 3x top-level category adverts. Placeholder content will be used.<!-- 45m -->

![Home: Categories](https://store.neto.com.au/assets/scopes/WHH/home-categories.png)

- A selection of 'Featured Products' displayed within a carousel, with mobile responsive swipe gestures. <!-- 45m -->
- A selection of 'New Arrivals' displayed within a carousel, with mobile responsive swipe gestures. <!-- 45m -->
  - *Please Note: These products will be sorted/displayed based on their upload date to your Neto site, you will not be able to manually change their order. If you would like to change the order, this will required modifying this section within this scope.*

![Home: Featured](https://store.neto.com.au/assets/scopes/WHH/home-featured.png)

---

## Footer (1hr 45m)

<!-- 
Coding 1hr
-->

![Footer](https://store.neto.com.au/assets/scopes/WHH/footer.png)

The footer will include the following elements:

- A utility menu, to display links to your information pages.
- Your phone number and company address, allowing people to easily reach you. <!-- 30m -->
- A newsletter subscription section, to help with building your mailing list.
  - *Neto Mail is the default mailing list unless otherwise specified.*
- A 'Scroll to Top' button.<!-- 15m -->

---

## Category Page (2hr 45m)

<!--
Coding 2hr
-->

The Category Page will include the following elements:

- Collapsible sidebar filters which allows the customer to expand/close the sections they’re looking to filter by. <!-- 30m -->
- Limit the height of the product filters by adding a scroll bar, to reduce the vertical space taken by the filters. <!-- 15m -->
- *Please Note: The 'Show 12/24 ect.' feature from your current site will not be included as it is not supported within Neto. You will instead be able to update the number of products to be displayed on all categories within the control panel.*

---

## Product Thumbnails (12hr)

### Homepage

<!--
Mockup (included within homepage)
Coding (included within homepage)
-->

![Home: Featured](https://store.neto.com.au/assets/scopes/WHH/home-featured.png)

The design of the Homepage Product Thumbnails will be included within the homepage design, for you to approve before implementing the final design. This thumbnail will include:

- The product image, name and price.
- When hovering on the product image, display the following:<!-- 30m -->
  - The buying options button.
  - A 'Quick View' link that opens a pop-up window outlined below.
  - *Please Note: The 'Quick View' link will only be displayed on desktop devices.*

### Category

<!--
Mockup 45m
Coding 1hr
-->

![Category: Thumbnails](https://store.neto.com.au/assets/scopes/WHH/category-thumbnails.png)

We'll create a design of the Category Page Product Thumbnail for you to approve before implementing the final design. This popup will include:

- The product image, name, price and the buying options button.
- An Afterpay advert that displays the breakdown of payments based on the product price. <!-- 30m -->
- When hovering on the product image, display the following:<!-- 30m -->
  - A wishlist button.
  - A 'Quick View' link that opens a pop-up window outlined below.
  - *Please Note: The 'Quick View' link will only be displayed on desktop devices.*

### Quick View

<!--
Wireframe 1hr 30m
Mockup 2hr 30m 
Coding 3hr 30m
-->

![Quick View](https://store.neto.com.au/assets/scopes/WHH/quick-view.png)

We'll create a design of the Quick View Popup for you to approve before implementing the final design. This popup will include:

- Main product image
- Product name
- Review stars
- Short description
- Pricing
- An Afterpay advert that displays the breakdown of payments based on the product price. <!-- 30m -->
- Product variations if applicable
- The quantity input field with plus and minus buttons, which can increase or decrease the quantity value. <!-- 45m -->
- Buying options
- A link to the product page to view more information

---

## Product Page (15hr 45m)

<!--
Wireframe 3hr
Mockup 4hr 
Coding 5hr
-->

![Product Page](https://store.neto.com.au/assets/scopes/WHH/product-page.png)

We'll create a design of the product page for you to approve before implementing the final design. This page will include:

- The product image, name, price and the buying options button.
- An Afterpay advert that displays the breakdown of payments based on the product price. <!-- 30m -->
- The quantity input field with plus and minus buttons, which can increase or decrease the quantity value. <!-- 45m -->
- *Please Note: The 'Tags' feature from your current site will not be included as it is not supported within Neto.*
- The following USPs (unique selling points), which boost customer confidence (we can change/remove any of these which aren't applicable). Each USP will contain a title, short description and icon. <!-- 1hr -->
  - Fast Shipping
  - Lowest Prices
  - Attentive Support
- An image based Advertising Group displayed within a carousel, with mobile responsive swipe gestures.<!-- 1hr 30m -->

---

## Important Notes

- Any pages not included in the above scope will be displayed as per our base eCommerce framework, with your branding/colours applied.
- When a mockup isn't included, we'll use our design expertise when it comes to the final look. If you have specific requirements regarding the aesthetic please let us know before work starts. Alternatively, we can include a billable mockup in the quote, which allows you to request changes to the design.
- Any functionality not outlined in the above scope, even if it is present on your existing site, any example sites you provided for inspiration, or mentioned in scoping discussions, will not be included as part of the quoted amount below, and may attract additional billable time.
- Unless specified, changes to the checkout page, print documents (e.g. invoices) or system emails (e.g. order confirmation) will not be included.
- Theme editor functionality is not available for custom designs.

---

The above work requires **68.5 hours** of design time, which comes to **$10,960** in total (ex.GST). All design projects that have been quoted over 10 hours of work have terms of 50% project due upfront and 50% invoiced after the declared milestone, which for this project is **Category Page: Product Thumbnail Design Deliverable*. Once received, we'll proceed with the next phase of the project.

Please note that this quote is purely for design; it doesn't cover monthly subscription fees or additional services.

## Deliverables

### Home Page Phase

The Home Page Phase is the basis of design for the whole project, therefore it is required to have these pages approved before commencing work on any remaining design deliverables.

We'll aim to get the first draft of the designs completed within the first week.

The design process is collaborative so once you see the first draft we welcome any feedback you may have and we'll collectively work towards having these deliverables approved by week 2.

- 1.1 - Home Page Design Deliverable (week 2)

### Additional Mockup Phase

This phase commences upon the completion of the **Home Page Phase**.

- 1.2 - Mobile Header & Menu Design Deliverable (week 3)
- 1.3 - Megamenu Design Deliverable (week 3)
- 1.4 - Product Page Design Deliverable (week 4)
- 1.5 - Quick View Design Deliverable (week 4)
- 1.6 - Category Page: Product Thumbnail Design Deliverable (week 4)

### Implementation Phase

Once you've approved all of the design deliverables, we'll move onto implementation. Once complete, we'll deliver the following:

- 2.1 - A link to the finished design, for you to browse and review. (week 8)
- 2.2 - Custom feature notes, to assist you in working with your new design. (week 8)

<!-- 
Total Mockup Hours: 26.25hr
Total Coding Hours: 42.25hr
- Home Page Implementation 23.5hr
- Category Page Implementation 2.75hr
- Product Page Implementation 8.75hr
- Product Thumbnails Implementation 7.25hr
- Review and Testing
-->

At the time of scoping your project requirements it will take **8 weeks** from initial payment to complete the project. This is subject to change if the project isn’t accepted within a week of receiving the proposal to accommodate our existing projects.

After the implementation phase is complete, there tends to be a review period in the following weeks whereby you test the design to ensure that it works well with your data (products, categories, content, etc.) that is being pulled from your Neto control panel. Once this review is complete, your new design will be ready to go live.